==> huaweicloudsdkservicestage-3.0.52-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/flavor_id.py <==
# coding: utf-8

import re
import six





class FlavorId:
    """
    allowed enum values
    """

    MICRO_5G_0_5C_1G = "MICRO-5G:0.5C:1G"
    SMALL_10G_1_0C_2G = "SMALL-10G:1.0C:2G"
    STANDARD_30G_2_0C_4G = "STANDARD-30G:2.0C:4G"
    LARGE_50G_4_0C_8G = "LARGE-50G:4.0C:8G"
    XLARGE_100G_4_0C_16G = "XLARGE-100G:4.0C:16G"
    CUSTOM_XG_X_X_X_X = "CUSTOM-XG:X-X:X-X"

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self):
        """FlavorId - a model defined in huaweicloud sdk"""
        
        
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FlavorId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkservicestage-3.0.54-py2.py3-none-any.whl: huaweicloudsdkservicestage/v2/model/flavor_id.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FlavorId:
    """
    allowed enum values
    """

    MICRO_5G_0_5C_1G = "MICRO-5G:0.5C:1G"
    SMALL_10G_1_0C_2G = "SMALL-10G:1.0C:2G"
    STANDARD_30G_2_0C_4G = "STANDARD-30G:2.0C:4G"
    LARGE_50G_4_0C_8G = "LARGE-50G:4.0C:8G"
    XLARGE_100G_4_0C_16G = "XLARGE-100G:4.0C:16G"
    CUSTOM_XG_X_X_X_X = "CUSTOM-XG:X-X:X-X"

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self):
        """FlavorId - a model defined in huaweicloud sdk"""
        
        
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FlavorId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
